==> immibis-core_50.0.2_for_1.3.2-joined.jar: mod_shared/immibis/core/porting/ServerProxy132.java <==
package immibis.core.porting;

/* $if jserver && mc == 1.3.2$ */

import immibis.core.api.porting.IClientPacketHandler;
import immibis.core.api.porting.IServerPacketHandler;
import immibis.core.api.porting.PortableBaseMod;
import immibis.core.api.porting.PortableGuiHandler;

import java.io.File;

import cpw.mods.fml.common.Side;
import cpw.mods.fml.common.network.IGuiHandler;
import cpw.mods.fml.common.network.IPacketHandler;
import cpw.mods.fml.common.network.NetworkRegistry;
import cpw.mods.fml.common.network.PacketDispatcher;
import cpw.mods.fml.common.network.Player;
import cpw.mods.fml.common.registry.GameRegistry;

import net.minecraft.server.MinecraftServer;
import net.minecraft.src.Entity;
import net.minecraft.src.EntityPlayer;
import net.minecraft.src.NetworkManager;
import net.minecraft.src.Packet250CustomPayload;
import net.minecraft.src.TileEntity;
import net.minecraft.src.World;

public class ServerProxy132 extends CommonProxy132 {

	public File getMinecraftDir() {
		return new File(".");
	}
	
	public double getPlayerReach(EntityPlayer ply) {
		throw new UnsupportedOperationException();
	}
	
	public EntityPlayer getThePlayer() {
		return null;
	}
	
	public int getUniqueBlockModelID(String renderClass, boolean b) {
		return 0;
	}
	
	public boolean isOp(String player) {
		return MinecraftServer.getServer().getConfigurationManager().areCommandsAllowed(player);
	}
	
	public void preloadTexture(String texfile) {
	}
	
	public void registerTileEntity(Class<? extends TileEntity> clazz, String id, String rclass) {
		GameRegistry.registerTileEntity(clazz, id);
	}
	
	public void registerItemRenderer(int itemID, String renderClassName) {
	}
	
	public void registerServerPacketHandler(String channel, final IServerPacketHandler handler) {
		NetworkRegistry.instance().registerChannel(new IPacketHandler() {
			@Override
			public void onPacketData(NetworkManager manager, Packet250CustomPayload packet, Player player) {
				if(player instanceof EntityPlayer)
					handler.onPacketData(manager, packet.channel, packet.data, (EntityPlayer)player);
			}
		}, channel, Side.SERVER);
	}
	
	public void registerClientPacketHandler(String channel, IClientPacketHandler handler) {
	}
	public void sendPacket(Packet250CustomPayload wrap, EntityPlayer player) {
		if(player instanceof Player)
			PacketDispatcher.sendPacketToPlayer(wrap, (Player)player);
	}
	public void setGuiHandler(PortableBaseMod mod, final PortableGuiHandler handler) {
		NetworkRegistry.instance().registerGuiHandler(mod, new IGuiHandler() {
			
			@Override
			public Object getServerGuiElement(int ID, EntityPlayer player, World world,
					int x, int y, int z) {
				return handler.getServerGuiElement(ID, player, world, x, y, z);
			}
			
			@Override
			public Object getClientGuiElement(int ID, EntityPlayer player, World world,
					int x, int y, int z) {
				return null;
			}
		});
	}
	
	public boolean isClient(Entity e) {
		return false;
	}
	public boolean isServer(Entity e) {
		return true;
	}
	
	public boolean isDedicatedServer() {
		return true;
	}
}

/* $endif$ */

==> immibis-core_50.2.4_for_1.4.2-joined.jar: mod_shared/immibis/core/porting/ServerProxy132.java <==
package immibis.core.porting;

/* $if jserver && mc == 1.3.2$ */

import immibis.core.api.porting.IClientPacketHandler;
import immibis.core.api.porting.IServerPacketHandler;
import immibis.core.api.porting.PortableBaseMod;
import immibis.core.api.porting.PortableGuiHandler;

import java.io.File;

import cpw.mods.fml.common.Side;
import cpw.mods.fml.common.network.IGuiHandler;
import cpw.mods.fml.common.network.IPacketHandler;
import cpw.mods.fml.common.network.NetworkRegistry;
import cpw.mods.fml.common.network.PacketDispatcher;
import cpw.mods.fml.common.network.Player;
import cpw.mods.fml.common.registry.GameRegistry;

import net.minecraft.server.MinecraftServer;
import net.minecraft.src.Entity;
import net.minecraft.src.EntityPlayer;
import net.minecraft.src.NetworkManager;
import net.minecraft.src.Packet250CustomPayload;
import net.minecraft.src.TileEntity;
import net.minecraft.src.World;

public class ServerProxy132 extends CommonProxy132 {

	public File getMinecraftDir() {
		return new File(".");
	}
	
	public double getPlayerReach(EntityPlayer ply) {
		throw new UnsupportedOperationException();
	}
	
	public EntityPlayer getThePlayer() {
		return null;
	}
	
	public int getUniqueBlockModelID(String renderClass, boolean b) {
		return 0;
	}
	
	public boolean isOp(String player) {
		return MinecraftServer.getServer().getConfigurationManager().areCommandsAllowed(player);
	}
	
	public void preloadTexture(String texfile) {
	}
	
	public void registerTileEntity(Class<? extends TileEntity> clazz, String id, String rclass) {
		GameRegistry.registerTileEntity(clazz, id);
	}
	
	public void registerItemRenderer(int itemID, String renderClassName) {
	}
	
	public void registerServerPacketHandler(String channel, final IServerPacketHandler handler) {
		NetworkRegistry.instance().registerChannel(new IPacketHandler() {
			@Override
			public void onPacketData(NetworkManager manager, Packet250CustomPayload packet, Player player) {
				if(player instanceof EntityPlayer)
					handler.onPacketData(packet.channel, packet.data, (EntityPlayer)player);
			}
		}, channel, Side.SERVER);
	}
	
	public void registerClientPacketHandler(String channel, IClientPacketHandler handler) {
	}
	public void sendPacket(Packet250CustomPayload wrap, EntityPlayer player) {
		if(player instanceof Player)
			PacketDispatcher.sendPacketToPlayer(wrap, (Player)player);
	}
	public void setGuiHandler(PortableBaseMod mod, final PortableGuiHandler handler) {
		NetworkRegistry.instance().registerGuiHandler(mod, new IGuiHandler() {
			
			@Override
			public Object getServerGuiElement(int ID, EntityPlayer player, World world,
					int x, int y, int z) {
				return handler.getServerGuiElement(ID, player, world, x, y, z);
			}
			
			@Override
			public Object getClientGuiElement(int ID, EntityPlayer player, World world,
					int x, int y, int z) {
				return null;
			}
		});
	}
	
	public boolean isClient(Entity e) {
		return false;
	}
	public boolean isServer(Entity e) {
		return true;
	}
	
	public boolean isDedicatedServer() {
		return true;
	}
}

/* $endif$ */
